package account

import (
	"context"
	"fonchain-fiee/api/account"
	"fonchain-fiee/pkg/config"
	"fonchain-fiee/pkg/e"
	"fonchain-fiee/pkg/model/union"
	"fonchain-fiee/pkg/service"
	"github.com/gin-gonic/gin"
	"github.com/gin-gonic/gin/binding"
)

// SendMsg 用户登录操作
func SendMsg(c *gin.Context) {

	var req account.SendMsgRequest

	if err := c.ShouldBindBodyWith(&req, binding.JSON); err != nil {
		service.Error(c, err)
		return
	}

	req.SignNo = uint32(config.DefaultSignNo)
	res, err := service.AccountProvider.SendMsg(context.Background(), &req)
	if err != nil {
		service.Error(c, err)
		return
	}

	service.Success(c, res)
	return
}
func RealName(c *gin.Context) {
	var req account.RealNameRequest

	if err := c.ShouldBindBodyWith(&req, binding.JSON); err != nil {
		service.Error(c, err)
		return
	}
	res, err := service.AccountProvider.RealName(context.Background(), &req)
	if err != nil {
		service.Error(c, err)
		return
	}

	service.Success(c, res)
	return
}

// CheckMsg 验证码是否正确
func CheckMsg(c *gin.Context) {

	var req account.CheckMsgRequest

	if err := c.ShouldBindBodyWith(&req, binding.JSON); err != nil {
		service.Error(c, err)
		return
	}

	res, err := service.AccountProvider.CheckMsg(context.Background(), &req)
	if err != nil {
		service.Error(c, err)
		return
	}

	service.Success(c, res)
	return
}

func UserLogout(c *gin.Context) {
	req := account.DecryptJwtRequest{}
	req.Token = c.GetHeader(e.Authorization)
	res, err := service.AccountProvider.Logout(c, &req)
	if err != nil {
		service.Error(c, err)
		return
	}

	service.Success(c, res)
	return
}
func UserRegister(c *gin.Context) {
	var req account.RegistRequest
	if err := c.ShouldBindBodyWith(&req, binding.JSON); err != nil {
		service.Error(c, err)
		return
	}
	req.Domain = "app"
	res, err := service.AccountProvider.Register(context.Background(), &req)
	if err != nil {
		service.Error(c, err)
	}
	tokenInfo, err := service.AccountProvider.Login(context.Background(), &account.LoginRequest{
		Domain: req.Domain,
		TelNum: req.TelNum,
		Code:   req.Code,
	})
	if err != nil {
		service.Error(c, err)
	}
	res.Token = tokenInfo.Token
	service.Success(c, res)
}

// UserLogin 用户登录操作
func UserLogin(c *gin.Context) {
	var req account.LoginRequest
	if err := c.ShouldBindBodyWith(&req, binding.JSON); err != nil {
		service.Error(c, err)
		return
	}
	req.Ip = c.ClientIP()
	req.Domain = "fontree"
	res, err := service.AccountProvider.Login(c, &req)
	if err != nil {
		service.Error(c, err)
		return
	}

	accountInfo := &union.AccountInfo{
		ID:           res.AccountInfo.ID,
		Account:      res.AccountInfo.Account,
		NickName:     res.AccountInfo.NickName,
		Domain:       res.AccountInfo.Domain,
		TelNum:       res.AccountInfo.TelNum,
		Avatar:       res.AccountInfo.Avatar,
		CreatedAt:    res.AccountInfo.CreateAt,
		IsNeedChange: res.AccountInfo.IsNeedChange,
		Sex:          res.AccountInfo.Sex,
	}
	resInfo := &union.Login{
		Token:        res.Token,
		RefreshToken: res.RefreshToken,
		AccountInfo:  accountInfo,
		//JumpToWhere:  jumpToWhere,
	}

	service.Success(c, resInfo)

	return
}
